// This file is part of Invenio.
// Copyright (C) 2015 CERN.
//
// Invenio is free software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// Invenio is distributed in the hope that it will be
// useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Invenio; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
// MA 02111-1307, USA.
//
// In applying this license, CERN does not
// waive the privileges and immunities granted to it by virtue of its status
// as an Intergovernmental Organization or submit itself to any jurisdiction.

@import "variables";

// Setting the path to fonts files.
$icon-font-path: "/static/node_modules/bootstrap-sass/assets/fonts/";
$fa-font-path: "/static/node_modules/font-awesome/fonts";

@import "../../node_modules/bootstrap-sass/assets/stylesheets/_bootstrap";
@import "../../node_modules/font-awesome/scss/font-awesome";

@import "type";
@import "navbar";
@import "body";
@import "cover";
@import "header";
@import "footer";
@import "input-icon";
