{#
# This file is part of Invenio.
# Copyright (C) 2015, 2016 CERN.
#
# Invenio is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# Invenio is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Invenio; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA 02111-1307, USA.
#
# In applying this license, CERN does not
# waive the privileges and immunities granted to it by virtue of its status
# as an Intergovernmental Organization or submit itself to any jurisdiction.
#}

{%- extends config.THEME_BASE_TEMPLATE %}

{%- block page_body scoped %}
<div class="container">
  <div class="row">
      <div class="col-sm-3 col-md-3 col-pad-left-0">
        {%- block settings_menu scoped %}
        <div class="panel-group">
          <div class="panel panel-default">
            <div class="panel-heading"><strong>{{ _('Settings') }}</strong></div>
            <ul class="list-group">
            {%- for item in current_menu.submenu('settings').children if item.visible %}
            {%- block settings_menu_item scoped %}
              <a href="{{ item.url }}" class="list-group-item{% if item.active %} active{% endif %}">
                {{ item.text|safe }}
              </a>
            {%- endblock %}
            {%- endfor %}
            </ul>
          </div>
        </div>
        {%- endblock %}
      </div>
      <div class="col-sm-9 col-md-9 col-pad-right-0">
        {%- block settings_content scoped %}
        <div class="panel-group panel-bot-margin">
          <div class="panel panel-default">
            <div class="panel-heading">
              {%- block settings_content_title scoped %}
              {%- if panel_icon %}
              {%- block settings_content_title_icon scoped %}
              <i class="{{panel_icon}}"></i>
              {%- endblock %}
              {%- endif %}
              <strong>{{ panel_title|default("") }}</strong>
              {%- endblock %}
            </div>
            {%- block settings_body scoped %}
            <div class="panel-body">
              {%- block settings_form scoped %}
              {%- endblock settings_form %}
            </div>
            {%- endblock settings_body %}
          </div>
        </div>
        {%- endblock %}
      </div>
  </div>
</div>
{%- endblock %}
