// This file is part of Invenio.
// Copyright (C) 2015 CERN.
//
// Invenio is free software; you can redistribute it
// and/or modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// Invenio is distributed in the hope that it will be
// useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Invenio; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
// MA 02111-1307, USA.
//
// In applying this license, CERN does not
// waive the privileges and immunities granted to it by virtue of its status
// as an Intergovernmental Organization or submit itself to any jurisdiction.

$navbar-height: 60px;
$brand-font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !default;
$brand-font-size: 30px;

$color1: #f5f5f5;
$color1-gradient: lighten($color1, 15%);
$color2: #90C5A9;
$color3: #7A9A95;
$color4: #EF6D3B;
$color5: #FA8B60;

$navbar-brand-padding-vertical: 10px;
$navbar-default-bg: $color1;
$navbar-default-border: #e5e5e5;

$text-white: #fff;
